@@ -41,8 +41,19 @@ fn main() {
 
 fn dump_file(path: &Path) -> Result<(), exif::Error> {
     let file = File::open(path)?;
-    let exif = exif::Reader::new().read_from_container(
-        &mut BufReader::new(&file))?;
+
+    // To parse strictly:
+    // let exif = exif::Reader::new()
+    //     .read_from_container(&mut BufReader::new(&file))?;
+
+    // To parse with continue-on-error mode:
+    let exif = exif::Reader::new()
+        .continue_on_error(true)
+        .read_from_container(&mut BufReader::new(&file))
+        .or_else(|e| e.distill_partial_result(|errors| {
+            eprintln!("{}: {} warning(s)", path.display(), errors.len());
+            errors.iter().for_each(|e| eprintln!("  {}", e));
+        }))?;
 
     println!("{}", path.display());
     for f in exif.fields() {
